// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

// ignore_for_file: constant_identifier_names

import 'dart:io';

const int ARROW_UP = 65;
const int ARROW_DOWN = 66;
const int ENTER = 10;
const int SPACE = 32;

const int WIN_UP = 119;
const int WIN_DOWN = 115;
const int WIN_ENTER = 13;
const int WIN_SPACE = 20;

/// Abstract class providing some key codes which can be statically accessed.
abstract class Keys {
  /// Arrow down. Consists of three bytes.
  /// For historical reasons, you can also use 's'
  /// instead of arrow down on Windows.
  ///
  /// It is packed into a single element list in
  /// order to not break the spread syntax.
  static final List<int> arrowDown =
      Platform.isWindows ? <int>[WIN_DOWN] : <int>[27, 91, 66];

  /// Arrows up. Consists of three bytes in Unix like systems (including MacOS).
  /// For historical reasons, you can also use 'w' insted of arrow
  /// up on Windows.
  ///
  /// It is packed into a single element list in
  /// order to not break the spread syntax.
  static final List<int> arrowUp =
      Platform.isWindows ? <int>[WIN_UP] : <int>[27, 91, 65];

  /// Enter key. Single byte.
  static final int enter = Platform.isWindows ? WIN_ENTER : ENTER;

  /// Space key. Single byte.
  static final int space = Platform.isWindows ? WIN_SPACE : SPACE;
}
